@@ -140,7 +140,11 @@ class TestQiskitBackend(QuantumBackendTests):
     ):
         # Given
         extracted_pickle_objects = open(
-            "jobs_and_batches_with_different_qubits.pickle", "rb"
+            os.path.join(
+                os.path.dirname(__file__),
+                "jobs_and_batches_with_different_qubits.pickle",
+            ),
+            "rb",
         )
         jobs = pickle.load(extracted_pickle_objects)
         batches = pickle.load(extracted_pickle_objects)
@@ -171,6 +175,9 @@ class TestQiskitBackend(QuantumBackendTests):
 
             counts = measurements.get_counts()
             assert max(counts, key=counts.get) == "1"
+        assert len(backend.list_virtual_to_physical_qubits_dict) == len(
+            measurements_set
+        )
 
     def test_execute_with_retries(self, backend):
         # This test has a race condition where the IBMQ server might finish
@@ -240,6 +247,9 @@ class TestQiskitBackend(QuantumBackendTests):
 
         # Then
         assert len(measurements_set) == num_circuits
+        assert len(backend.list_virtual_to_physical_qubits_dict) == len(
+            measurements_set
+        )
 
     def test_run_circuitset_and_measure_split_circuits_and_jobs(self, backend):
         # Given
@@ -259,6 +269,9 @@ class TestQiskitBackend(QuantumBackendTests):
         )
         # Then
         assert len(measurements_set) == num_circuits
+        assert len(backend.list_virtual_to_physical_qubits_dict) == len(
+            measurements_set
+        )
         for measurements in measurements_set:
             assert len(measurements.bitstrings) == n_samples or len(
                 measurements.bitstrings
@@ -281,6 +294,10 @@ class TestQiskitBackend(QuantumBackendTests):
         # Then
         assert backend_with_readout_correction.readout_correction
         assert backend_with_readout_correction.readout_correction_filters is not None
+        assert (
+            len(backend_with_readout_correction.list_virtual_to_physical_qubits_dict)
+            == 1
+        )
 
     def test_readout_correction_for_distributed_circuit(
         self, backend_with_readout_correction
@@ -451,6 +468,9 @@ class TestQiskitBackend(QuantumBackendTests):
         assert len(measurements_set[1].bitstrings) >= n_samples[1]
 
         assert backend.number_of_circuits_run == 2
+        assert len(backend.list_virtual_to_physical_qubits_dict) == len(
+            measurements_set
+        )
 
     @pytest.mark.parametrize("n_samples", [1, 2, 10])
     def test_run_circuit_and_measure_correct_num_measurements_attribute(
